<?php
/**
 * Network Devices File
 *
 * This file lists all the devices to be monitored.
 *
 *
 * Common Params to all devices.
 *    subsytem: The subsystem on the device that is being checked
 *    hostname: The is the name that is displayed to the user for the device
 *    hostspec: The address used to connect to the device
 *    community: The SNMP Community to use. Default is 'public' and cannot be ''
 *
 * Common Params to most devices.
 *    port: The port used to connect to the device
 *
 * $Horde: nic/config/devices.php.dist,v 1.8 2005/03/21 21:08:47 chuck Exp $
 */

$devices = array();

/**
 * Example Squid Proxy Server
 */
$devices['proxy1']['driver'] = 'squid';
$devices['proxy1']['params'] = array();
$devices['proxy1']['params']['hostspec'] = 'proxy.example.com';
$devices['proxy1']['params']['port'] = '161'; // Squid SNMP port
$devices['proxy1']['params']['community'] = 'public';
$devices['proxy1']['params']['port'] = '3128'; // Squid listening port
$devices['proxy1']['params']['hostname'] = 'proxy.example.com';
$devices['proxy1']['params']['subsystem'] = 'Proxy';

/**
 * Example Jet Direct Printer
 */
$devices['printer1']['driver'] = 'jetdirect';
$devices['printer1']['params'] = array();
$devices['printer1']['params']['hostspec'] = 'printer.example.com';
$devices['printer1']['params']['port'] = '161';
$devices['printer1']['params']['community'] = 'public';
$devices['printer1']['params']['hostname'] = 'HP 2100 TN Printer';
$devices['printer1']['params']['subsystem'] = 'Printer';

/**
 * Example Windows 2000 Server
 */
$devices['server1']['driver'] = 'win2k';
$devices['server1']['params'] = array();
$devices['server1']['params']['hostspec'] = 'win2k.example.com';
$devices['server1']['params']['port'] = '161';
$devices['server1']['params']['community'] = 'public';
$devices['server1']['params']['hostname'] = 'Windows 2000 System';
$devices['server1']['params']['subsystem'] = 'Win2k';

/**
 * Example Apache Web Server
 */
$devices['www1']['driver'] = 'apache';
$devices['www1']['params'] = array();
$devices['www1']['params']['hostspec'] = 'apache.example.com';
$devices['www1']['params']['port'] = '80';
$devices['www1']['params']['hostname'] = 'apache.example.com';
/* Check /server-status? */
$devices['www1']['params']['status'] = true;
$devices['www1']['params']['subsystem'] = 'WWW';

/**
 * Example Web Server
 */
$devices['www2']['driver'] = 'www';
$devices['www2']['params'] = array();
$devices['www2']['params']['hostspec'] = 'www.example.com';
$devices['www2']['params']['port'] = '80';
$devices['www2']['params']['hostname'] = 'www.example.com';
$devices['www2']['params']['subsystem'] = 'WWW';

/**
 * Example DNS Server
 */
$devices['dns1']['driver'] = 'dns';
$devices['dns1']['params'] = array();
$devices['dns1']['params']['hostspec'] = 'dns.example.com';
$devices['dns1']['params']['target'] = 'google.com'; // Address to request
// $devices['dns1']['params']['type'] = 'MX'; // (optional) Type of request
$devices['dns1']['params']['hostname'] = 'dns.example.com';
$devices['dns1']['params']['subsystem'] = 'DNS';

/**
 * Example SMTP Server
 */
$devices['mail1']['driver'] = 'smtp';
$devices['mail1']['params'] = array();
$devices['mail1']['params']['hostspec'] = 'smtp.example.com';
$devices['mail1']['params']['port'] = '25';
$devices['mail1']['params']['hostname'] = 'smtp.example.com';
$devices['mail1']['params']['subsystem'] = 'SMTP';

/**
 * Example IMAP Server
 */
$devices['mail2']['driver'] = 'imap';
$devices['mail2']['params'] = array();
$devices['mail2']['params']['hostspec'] = 'imap.example.com';
$devices['mail2']['params']['port'] = '143';
$devices['mail2']['params']['hostname'] = 'imap.example.com';
$devices['mail2']['params']['subsystem'] = 'IMAP';

/**
 * Example POP3 Server
 */
$devices['mail3']['driver'] = 'pop3';
$devices['mail3']['params'] = array();
$devices['mail3']['params']['hostspec'] = 'pop3.example.com';
$devices['mail3']['params']['port'] = '110';
$devices['mail3']['params']['hostname'] = 'pop3.example.com';
$devices['mail3']['params']['subsystem'] = 'POP3';

/**
 * Example MySQL Server
 */
$devices['db1']['driver'] = 'mysql';
$devices['db1']['params'] = array();
$devices['db1']['params']['hostspec'] = 'localhost';
$devices['db1']['params']['user'] = 'horde';
$devices['db1']['params']['password'] = '****';
$devices['db1']['params']['hostname'] = 'db.example.com';
$devices['db1']['params']['subsystem'] = 'MySQL';

/**
 * Example Xi1500/Xi1510 Wireless Access Point
 */
$devices['ap1']['driver'] = 'xi1510';
$devices['ap1']['params'] = array();
$devices['ap1']['params']['hostspec'] = 'ap1.example.com';
$devices['ap1']['params']['port'] = '161';
$devices['ap1']['params']['community'] = 'public';
$devices['ap1']['params']['hostname'] = 'AP-One';
$devices['ap1']['params']['subsystem'] = 'Access Point';

/**
 * Example Generic Router
 */
$devices['r1']['driver'] = 'SNMPCustom';
$devices['r1']['params'] = array();
$devices['r1']['params']['hostspec'] = '172.20.0.1';
$devices['r1']['params']['port'] = '';
$devices['r1']['params']['community'] = 'public';
$devices['r1']['params']['hostname'] = 'router.example.com';
$devices['r1']['params']['subsystem'] = 'Router';
$devices['r1']['params']['oids'] = array(
    array('name' => 'Ethernet 0/0 In', 'oid' => '.1.3.6.1.2.1.2.2.1.10.1'),
    array('name' => 'Ethernet 0/0 Out', 'oid' => '.1.3.6.1.2.1.2.2.1.16.1'),
    array('name' => 'Ethernet 0/1 In', 'oid' => '.1.3.6.1.2.1.2.2.1.10.3'),
    array('name' => 'Ethernet 0/1 Out', 'oid' => '.1.3.6.1.2.1.2.2.1.16.3'),
);

/**
 * Example Generic Router with RRDTool options
 */
$devices['r1']['driver'] = 'SNMPCustom';
$devices['r1']['params'] = array();
$devices['r1']['params']['hostspec'] = '172.20.0.1';
$devices['r1']['params']['port'] = '';
$devices['r1']['params']['community'] = 'public';
$devices['r1']['params']['hostname'] = 'router.example.com';
$devices['r1']['params']['subsystem'] = 'Router';
$devices['r1']['params']['oids'] = array(
    array('name' => 'Ethernet 0/0 In', 'oid' => '.1.3.6.1.2.1.2.2.1.10.1', 'rrdtool' => 'corp101'),
    array('name' => 'Ethernet 0/0 Out', 'oid' => '.1.3.6.1.2.1.2.2.1.16.1', 'rrdtool' => 'corp161'),
    array('name' => 'Ethernet 0/1 In', 'oid' => '.1.3.6.1.2.1.2.2.1.10.3', 'rrdtool' => 'corp103'),
    array('name' => 'Ethernet 0/1 Out', 'oid' => '.1.3.6.1.2.1.2.2.1.16.3', 'rrdtool' => 'corp161'),
);

$rrdtools['corp101'] = array('file' => 'RRDFileName-0',
                             'name' => 'In',
                             'color' => '#00CC00',
                             'line' => 'LINE1',
                             'unit' => 'kB/s',
                             'text_calc' => '',
                             'graph_calc' => '');
$rrdtools['corp161'] = array('file' => 'RRDFilename-0',
                             'name' => 'Out',
                             'color' => '#0000FF',
                             'line' => 'AREA',
                             'unit' => 'kB/s',
                             'text_calc' => '',
                             'graph_calc' => '');
$rrdtools['corp103'] = array('file' => 'RRDFilename-1',
                             'name' => 'In',
                             'color' => '#00CC00',
                             'line' => 'LINE2',
                             'unit' => 'kB/s',
                             'text_calc' => '',
                             'graph_calc' => '1000,/');
$rrdtools['corp163'] = array('file' => 'RRDFilename-1',
                             'name' => 'Out',
                             'color' => '#0000FF',
                             'line' => 'AREA',
                             'unit' => 'kB/s',
                             'text_calc' => '-1,*',
                             'graph_calc' => '1000,/');
